@@ -168,6 +168,16 @@ test_fundamental_get_ref_function_pointer (GIRepository *repo)
     g_base_info_unref (info);
 }
 
+static void
+test_hash_with_cairo_typelib (GIRepository *repo)
+{
+    GIBaseInfo *info;
+
+    g_assert (g_irepository_require (repo, "cairo", NULL, 0, NULL));
+    info = g_irepository_find_by_name (repo, "cairo", "region");
+    g_assert (info == NULL);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -183,6 +193,7 @@ main(int argc, char **argv)
     test_size_of_gvalue (repo);
     test_is_pointer_for_struct_arg (repo);
     test_fundamental_get_ref_function_pointer (repo);
+    test_hash_with_cairo_typelib (repo);
 
     exit(0);
 }
